@@ -60,7 +60,7 @@ public class HelpPanel extends FramedPanel {
 
 	public void addContents() {
 		HtmlLayoutContainer title = new HtmlLayoutContainer("<H2>" + msgs.helpPanelTitle() + "<H2>");
-		vl.add(title, new VerticalLayoutData(-1, -1, new Margins(1, 1, 10, 1)));
+		vl.add(title, new VerticalLayoutData(-1, -1, new Margins(1, 0, 10, 1)));
 
 		contents = new FieldSet();
 		contents.setHeadingText(msgs.contents());
@@ -86,10 +86,10 @@ public class HelpPanel extends FramedPanel {
 		};
 		wikiButton.addSelectHandler(wikiHandler);
 
-		layoutCaptions.add(info, new VerticalLayoutData(1, -1, new Margins(1)));
+		layoutCaptions.add(info, new VerticalLayoutData(1, -1, new Margins(0)));
 		layoutCaptions.add(wikiButton, new VerticalLayoutData(-1, -1,
-				new Margins(1)));
-		vl.add(contents, new VerticalLayoutData(1, -1, new Margins(1)));
+				new Margins(0)));
+		vl.add(contents, new VerticalLayoutData(1, -1, new Margins(1,0,1,1)));
 
 	}
 
